@@ -1,5 +1,4 @@
 # SNMP::Info::Bridge
-# $Id$
 #
 # Changes since Version 0.7 Copyright (c) 2004 Max Baker
 # All rights reserved.
@@ -34,15 +33,16 @@
 package SNMP::Info::Bridge;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info;
 
 @SNMP::Info::Bridge::ISA       = qw/SNMP::Info Exporter/;
 @SNMP::Info::Bridge::EXPORT_OK = qw//;
 
-use vars qw/$VERSION $DEBUG %MIBS %FUNCS %GLOBALS %MUNGE $INIT/;
+our ($VERSION, $DEBUG, %MIBS, %FUNCS, %GLOBALS, %MUNGE, $INIT);
 
-$VERSION = '3.65';
+$VERSION = '3.70';
 
 %MIBS = (
     'BRIDGE-MIB'   => 'dot1dBaseBridgeAddress',
@@ -242,8 +242,10 @@ sub qb_fdb_index {
 sub fw_mac {
     my $bridge = shift;
 
-    my $qb = $bridge->qb_fw_mac();
-    return $qb if (ref {} eq ref $qb and scalar keys %$qb);
+    unless ($bridge->can('cisco_comm_indexing') && $bridge->cisco_comm_indexing()){
+        my $qb = $bridge->qb_fw_mac();
+        return $qb if (ref {} eq ref $qb and scalar keys %$qb);
+    }
 
     return $bridge->SUPER::fw_mac();
 }
@@ -251,8 +253,10 @@ sub fw_mac {
 sub fw_port {
     my $bridge = shift;
 
-    my $qb = $bridge->qb_fw_port();
-    return $qb if (ref {} eq ref $qb and scalar keys %$qb);
+    unless ($bridge->can('cisco_comm_indexing') && $bridge->cisco_comm_indexing()){
+        my $qb = $bridge->qb_fw_port();
+        return $qb if (ref {} eq ref $qb and scalar keys %$qb);
+    }
 
     return $bridge->SUPER::fw_port();
 }
@@ -260,8 +264,10 @@ sub fw_port {
 sub fw_status {
     my $bridge = shift;
 
-    my $qb = $bridge->qb_fw_status();
-    return $qb if (ref {} eq ref $qb and scalar keys %$qb);
+    unless ($bridge->can('cisco_comm_indexing') && $bridge->cisco_comm_indexing()){
+        my $qb = $bridge->qb_fw_status();
+        return $qb if (ref {} eq ref $qb and scalar keys %$qb);
+    }
 
     return $bridge->SUPER::fw_status();
 }
@@ -296,11 +302,11 @@ sub i_stp_port {
     my %i_stp_port;
 
     foreach my $index ( keys %$stp_p_port ) {
-        my $bridge = $stp_p_port->{$index};
+        my $bport  = $stp_p_port->{$index};
         my $iid    = $bp_index->{$index};
         next unless defined $iid;
-        next unless defined $bridge;
-        $i_stp_port{$iid} = $bridge;
+        next unless defined $bport;
+        $i_stp_port{$iid} = $bport;
     }
     return \%i_stp_port;
 }
@@ -315,11 +321,11 @@ sub i_stp_id {
     my %i_stp_id;
 
     foreach my $index ( keys %$stp_p_id ) {
-        my $bridge = $stp_p_id->{$index};
+        my $bport  = $stp_p_id->{$index};
         my $iid    = $bp_index->{$index};
         next unless defined $iid;
-        next unless defined $bridge;
-        $i_stp_id{$iid} = $bridge;
+        next unless defined $bport;
+        $i_stp_id{$iid} = $bport;
     }
     return \%i_stp_id;
 }
@@ -334,11 +340,11 @@ sub i_stp_bridge {
     my %i_stp_bridge;
 
     foreach my $index ( keys %$stp_p_bridge ) {
-        my $bridge = $stp_p_bridge->{$index};
+        my $bport  = $stp_p_bridge->{$index};
         my $iid    = $bp_index->{$index};
         next unless defined $iid;
-        next unless defined $bridge;
-        $i_stp_bridge{$iid} = $bridge;
+        next unless defined $bport;
+        $i_stp_bridge{$iid} = $bport;
     }
     return \%i_stp_bridge;
 }
@@ -609,12 +615,11 @@ None.
 
 =item F<Q-BRIDGE-MIB>
 
+=item F<RSTP-MIB>
+
 =back
 
-F<BRIDGE-MIB> needs to be extracted from
-ftp://ftp.cisco.com/pub/mibs/v1/v1.tar.gz
-
-=head1 GLOBAL METHODS
+=head1 GLOBALS
 
 These are methods that return scalar values from SNMP
 
