@@ -29,14 +29,14 @@
 package SNMP::Info::CiscoStpExtensions;
 
 use strict;
-
+use warnings;
 use Exporter;
 use SNMP::Info;
 use SNMP::Info::Bridge;
 
-use vars qw/$VERSION $DEBUG %MIBS %FUNCS %GLOBALS %MUNGE %PORTSTAT $INIT/;
+our ($VERSION, $DEBUG, %MIBS, %FUNCS, %GLOBALS, %MUNGE, %PORTSTAT, $INIT);
 
-$VERSION = '3.65';
+$VERSION = '3.70';
 
 @SNMP::Info::CiscoStpExtensions::ISA = qw/SNMP::Info::Bridge SNMP::Info Exporter/;
 @SNMP::Info::CiscoStpExtensions::EXPORT_OK = qw//;
@@ -317,9 +317,7 @@ For debugging you can call new() directly as you would in SNMP::Info
 
 =back
 
-MIBs can be found at ftp://ftp.cisco.com/pub/mibs/v2/v2.tar.gz
-
-=head1 GLOBAL METHODS
+=head1 GLOBALS
 
 These are methods that return scalar values from SNMP
 
