@@ -1,5 +1,4 @@
 # SNMP::Info::IEEE802dot11
-# $Id$
 #
 # Copyright (c) 2008 Eric Miller
 # All rights reserved.
@@ -31,15 +30,16 @@
 package SNMP::Info::IEEE802dot11;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info;
 
 @SNMP::Info::IEEE802dot11::ISA       = qw/SNMP::Info Exporter/;
 @SNMP::Info::IEEE802dot11::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %FUNCS %GLOBALS %MIBS %MUNGE/;
+our ($VERSION, %FUNCS, %GLOBALS, %MIBS, %MUNGE);
 
-$VERSION = '3.65';
+$VERSION = '3.70';
 
 %MIBS = ( 'IEEE802dot11-MIB' => 'dot11DesiredSSID', );
 
