@@ -30,15 +30,16 @@
 package SNMP::Info::Layer2::Sixnet;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info::Layer2;
 
 @SNMP::Info::Layer2::Sixnet::ISA       = qw/SNMP::Info::Layer2 Exporter/;
 @SNMP::Info::Layer2::Sixnet::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %GLOBALS %FUNCS %MIBS %MUNGE/;
+our ($VERSION, %GLOBALS, %FUNCS, %MIBS, %MUNGE);
 
-$VERSION = '3.65';
+$VERSION = '3.70';
 
 %MIBS = (%SNMP::Info::Layer2::MIBS, 'SIXNET-MIB' => 'sxid',);
 
@@ -108,11 +109,6 @@ Eric Miller
 SNMP::Info::Layer2::Sixnet is a subclass of SNMP::Info that provides an
 interface to Sixnet industrial switches.
 
-For speed or debugging purposes you can call the subclass directly, but not
-after determining a more specific class using the method above.
-
- my $sixnet = new SNMP::Info::Layer2::Sixnet(...);
-
 =head2 Inherited Classes
 
 =over
