@@ -1,5 +1,4 @@
 # SNMP::Info::Layer2::ZyXEL_DSLAM
-# $Id$
 #
 # Copyright (c) 2008 Max Baker
 # All rights reserved.
@@ -31,22 +30,23 @@
 package SNMP::Info::Layer2::ZyXEL_DSLAM;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info::Layer2;
 
 @SNMP::Info::Layer2::ZyXEL_DSLAM::ISA       = qw/SNMP::Info::Layer2 Exporter/;
 @SNMP::Info::Layer2::ZyXEL_DSLAM::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %FUNCS %GLOBALS %MIBS %MUNGE/;
+our ($VERSION, %FUNCS, %GLOBALS, %MIBS, %MUNGE);
 
-$VERSION = '3.39';
+$VERSION = '3.70';
 
 # Set for No CDP
 %GLOBALS = ( %SNMP::Info::Layer2::GLOBALS );
 
 %FUNCS = (
     %SNMP::Info::Layer2::FUNCS,
-    'ip_adresses'   => 'ipAdEntAddr',
+    'ip_addresses'  => 'ipAdEntAddr',
     'i_name'        => 'ifDescr',
     'i_description' => 'adslLineConfProfile',
 );
@@ -58,7 +58,7 @@ $VERSION = '3.39';
 
 sub layers {
     my $zyxel  = shift;
-    my $layers = $zyxel->layers();
+    my $layers = $zyxel->SUPER::layers();
     return $layers if defined $layers;
 
     # If these don't claim to have any layers, so we'll give them 1+2
@@ -77,7 +77,7 @@ sub os_ver {
     my $zyxel = shift;
     my $descr = $zyxel->description();
 
-    if ( $descr =~ m/version (\S+) / ) {
+    if ( defined ($descr) && $descr =~ m/version (\S+) / ) {
         return $1;
     }
     return;
@@ -88,11 +88,13 @@ sub model {
 
     my $desc = $zyxel->description();
 
-    if ( $desc =~ /8-port ADSL Module\(Annex A\)/ ) {
+    if (defined $desc) {
+      if ($desc =~ /8-port ADSL Module\(Annex A\)/) {
         return "AAM1008-61";
-    }
-    elsif ( $desc =~ /8-port ADSL Module\(Annex B\)/ ) {
+      }
+      elsif ($desc =~ /8-port ADSL Module\(Annex B\)/) {
         return "AAM1008-63";
+      }
     }
     return;
 }
@@ -102,7 +104,9 @@ sub ip {
     my $ip_hash = $zyxel->ip_addresses();
     my $found_ip;
 
-    foreach my $ip ( keys %{$ip_hash} ) {
+    # Since hashes are random add sort so we get the same address each time
+    # if there happens to be more than one. Will return highest numbered address
+    foreach my $ip ( sort keys %{$ip_hash} ) {
         $found_ip = $ip
             if ( defined $ip
             and $ip =~ /\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}$/ );
@@ -122,23 +126,23 @@ Dmitry Sergienko (C<dmitry@trifle.net>)
 
 =head1 SYNOPSIS
 
- # Let SNMP::Info determine the correct subclass for you. 
+ # Let SNMP::Info determine the correct subclass for you.
  my $zyxel = new SNMP::Info(
                           AutoSpecify => 1,
                           Debug       => 1,
                           DestHost    => 'myhub',
                           Community   => 'public',
-                          Version     => 1
-                        ) 
+                          Version     => 2
+                        )
     or die "Can't connect to DestHost.\n";
 
- my $class      = $l2->class();
+ my $class      = $zyxel->class();
  print "SNMP::Info determined this device to fall under subclass : $class\n";
 
 =head1 DESCRIPTION
 
-Provides abstraction to the configuration information obtainable from a 
-ZyXEL device through SNMP. See inherited classes' documentation for 
+Provides abstraction to the configuration information obtainable from a
+ZyXEL device through SNMP. See inherited classes' documentation for
 inherited methods.
 
 =head2 Inherited Classes
@@ -172,11 +176,11 @@ These are methods that return scalar value from SNMP
 
 =item $zyxel->vendor()
 
-Returns 'ZyXEL' :)
+Returns 'zyxel'
 
 =item $zyxel->os()
 
-Returns 'ZyXEL' 
+Returns 'zyxel'
 
 =item $zyxel->os_ver()
 
