@@ -1,5 +1,4 @@
 # SNMP::Info::Layer3::C4000
-# $Id$
 #
 # Copyright (c) 2008 Bill Fenner
 # All rights reserved.
@@ -42,9 +41,9 @@ use SNMP::Info::MAU;
     Exporter/;
 @SNMP::Info::Layer3::C4000::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %GLOBALS %MIBS %FUNCS %MUNGE/;
+our ($VERSION, %GLOBALS, %MIBS, %FUNCS, %MUNGE);
 
-$VERSION = '3.65';
+$VERSION = '3.70';
 
 %MIBS = (
     %SNMP::Info::MAU::MIBS,
@@ -129,11 +128,6 @@ Bill Fenner
 
 Abstraction subclass for Cisco Catalyst 4000 Layer 2/3 Switches.
 
-For speed or debugging purposes you can call the subclass directly, but not
-after determining a more specific class using the method above.
-
- my $c4000 = new SNMP::Info::Layer3::C4000(...);
-
 =head2 Inherited Classes
 
 =over
