@@ -1,5 +1,4 @@
 # SNMP::Info::Layer3::C6500
-# $Id$
 #
 # Copyright (c) 2008-2009 Max Baker
 # All rights reserved.
@@ -37,7 +36,7 @@ use SNMP::Info::CiscoStack;
 use SNMP::Info::Layer3::CiscoSwitch;
 use SNMP::Info::MAU;
 
-use vars qw/$VERSION %GLOBALS %MIBS %FUNCS %MUNGE/;
+our ($VERSION, %GLOBALS, %MIBS, %FUNCS, %MUNGE);
 
 # NOTE : Top-most items gets precedence for @ISA
 @SNMP::Info::Layer3::C6500::ISA = qw/
@@ -49,9 +48,7 @@ use vars qw/$VERSION %GLOBALS %MIBS %FUNCS %MUNGE/;
 
 @SNMP::Info::Layer3::C6500::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %GLOBALS %MIBS %FUNCS %MUNGE/;
-
-$VERSION = '3.39';
+$VERSION = '3.70';
 
 # NOTE: Order creates precedence
 #       Example: v_name exists in Bridge.pm and CiscoVTP.pm
@@ -179,7 +176,7 @@ sub set_i_duplex_admin {
 
     my $c6500 = shift;
     my ( $duplex, $iid ) = @_;
- 
+
     if ( $c6500->is_virtual_switch() ) {
 
         # VSS -> MAU
@@ -188,7 +185,7 @@ sub set_i_duplex_admin {
         # 2. Disable ifMauAutoNegAdminStatus
         # If the second set is not done, this is not going to be
         # working... Cisco Bug id CSCty97033.
-        # SXI is not working (up to at least relase SXI9).
+        # SXI is not working (up to at least release SXI9).
         # SXJ is working at SXJ3 (not before).
 
         return $c6500->mau_set_i_duplex_admin( $duplex, $iid );
@@ -226,7 +223,7 @@ sub set_i_speed_admin {
         # 2. Disable ifMauAutoNegAdminStatus
         # If the second set is not done, this is not going to be working...
         # Cisco Bug id CSCty97033.
-        # SXI is not working (at least up to relase SXI9).
+        # SXI is not working (at least up to release SXI9).
         # SXJ is working at SXJ3 (not before).
 
         return $c6500->mau_set_i_speed_admin( $speed, $iid );
@@ -244,7 +241,8 @@ __END__
 =head1 NAME
 
 SNMP::Info::Layer3::C6500 - SNMP Interface to Cisco Catalyst 6500 Layer 2/3
-Switches running IOS and/or CatOS
+Switches running IOS and/or CatOS. Also Cisco Catalyst 2960, 2970, 3750 and
+3850 series and blade switch CBS30x0 and CBS31x0 series running IOS.
 
 =head1 AUTHOR
 
@@ -252,7 +250,7 @@ Max Baker
 
 =head1 SYNOPSIS
 
- # Let SNMP::Info determine the correct subclass for you. 
+ # Let SNMP::Info determine the correct subclass for you.
  my $c6500 = new SNMP::Info(
                         AutoSpecify => 1,
                         Debug       => 1,
@@ -260,7 +258,7 @@ Max Baker
                         DestHost    => 'myswitch',
                         Community   => 'public',
                         Version     => 2
-                        ) 
+                        )
     or die "Can't connect to DestHost.\n";
 
  my $class      = $c6500->class();
@@ -268,16 +266,15 @@ Max Baker
 
 =head1 DESCRIPTION
 
-Abstraction subclass for Cisco Catalyst 6500 Layer 2/3 Switches.  
+Abstraction subclass for Cisco Catalyst 6500 Layer 2/3 Switches.
 
 These devices run IOS but have some of the same characteristics as the
 Catalyst WS-C family (5xxx). For example, forwarding tables are held in
 VLANs, and extended interface information is gleaned from F<CISCO-SWITCH-MIB>.
 
-For speed or debugging purposes you can call the subclass directly, but not
-after determining a more specific class using the method above. 
-
- my $c6500 = new SNMP::Info::Layer3::C6500(...);
+It also supports the following IOS only series switches: Cisco Catalyst 2960,
+2970, 3750 and 3850 series. Also blade switches from the CBS30x0 and CBS31x0
+series.
 
 =head2 Inherited Classes
 
@@ -295,6 +292,8 @@ after determining a more specific class using the method above.
 
 =over
 
+=item F<CISCO-VIRTUAL-SWITCH-MIB>
+
 =item Inherited Classes' MIBs
 
 See L<SNMP::Info::CiscoStack/"Required MIBs"> for its own MIB requirements.
@@ -314,7 +313,7 @@ These are methods that return scalar value from SNMP
 
 =item $c6500->vendor()
 
-    Returns 'cisco'
+Returns 'cisco'
 
 =item $c6500->cvsSwitchMode()
 
@@ -359,7 +358,7 @@ Newer software versions return duplex based upon the result of
 $c6500->el_duplex().  Otherwise it uses the result of the call to
 CiscoStack::i_duplex().
 
-See L<SNMP::Info::Etherlike> for el_duplex() method and
+See L<SNMP::Info::EtherLike> for el_duplex() method and
 L<SNMP::Info::CiscoStack> for its i_duplex() method.
 
 =item $c6500->i_duplex_admin()
@@ -382,7 +381,7 @@ Crosses $c6500->p_port() with $c6500->p_duplex() to utilize port C<ifIndex>.
 
     Example:
     my %if_map = reverse %{$c6500->interfaces()};
-    $c6500->set_i_duplex_admin('auto', $if_map{'FastEthernet0/1'}) 
+    $c6500->set_i_duplex_admin('auto', $if_map{'FastEthernet0/1'})
         or die "Couldn't change port duplex. ",$c6500->error(1);
 
 =item $c6500->set_i_speed_admin(speed, ifIndex)
@@ -399,13 +398,11 @@ Crosses $c6500->p_port() with $c6500->p_speed() to utilize port C<ifIndex>.
 
 See documentation in L<SNMP::Info::CiscoStack/"TABLE METHODS"> for details.
 
-
 =head2 Table Methods imported from SNMP::Info::Layer3::CiscoSwitch
 
 See documentation in L<SNMP::Info::Layer3::CiscoSwitch/"TABLE METHODS"> for
 details.
 
-
 =head2 Table Methods imported from SNMP::Info::MAU
 
 See documentation in L<SNMP::Info::MAU/"TABLE METHODS"> for details.
