@@ -1,6 +1,6 @@
 # SNMP::Info::Layer3::H3C
 #
-# Copyright (c) 2012 Jeroen van Ingen
+# Copyright (c) 2018 Jeroen van Ingen
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -30,14 +30,13 @@
 package SNMP::Info::Layer3::H3C;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info::Layer3;
-use SNMP::Info::LLDP;
 use SNMP::Info::IEEE802dot3ad 'agg_ports_lag';
 
 @SNMP::Info::Layer3::H3C::ISA = qw/
   SNMP::Info::IEEE802dot3ad
-  SNMP::Info::LLDP
   SNMP::Info::Layer3
   Exporter
 /;
@@ -45,13 +44,12 @@ use SNMP::Info::IEEE802dot3ad 'agg_ports_lag';
   agg_ports
 /;
 
-use vars qw/$VERSION %GLOBALS %MIBS %FUNCS %MUNGE/;
+our ($VERSION, %GLOBALS, %MIBS, %FUNCS, %MUNGE);
 
-$VERSION = '3.39';
+$VERSION = '3.70';
 
 %MIBS = (
     %SNMP::Info::Layer3::MIBS,
-    %SNMP::Info::LLDP::MIBS,
     %SNMP::Info::IEEE802dot3ad::MIBS,
     'HH3C-LswDEVM-MIB'     => 'hh3cDevMFanStatus',
     'HH3C-LswINF-MIB'      => 'hh3cSlotPortMax',
@@ -62,7 +60,6 @@ $VERSION = '3.39';
 
 %GLOBALS = (
     %SNMP::Info::Layer3::GLOBALS,
-    %SNMP::Info::LLDP::GLOBALS,
     'fan' => 'hh3cDevMFanStatus.1',
     'ps1_status' => 'hh3cDevMPowerStatus.1',
     'ps2_status' => 'hh3cDevMPowerStatus.2',
@@ -70,19 +67,33 @@ $VERSION = '3.39';
 
 %FUNCS = (
     %SNMP::Info::Layer3::FUNCS,
-    %SNMP::Info::LLDP::FUNCS,
+    %SNMP::Info::IEEE802dot3ad::FUNCS,
     i_duplex_admin => 'hh3cifEthernetDuplex',
 );
 
 %MUNGE = (
     %SNMP::Info::Layer3::MUNGE,
-    %SNMP::Info::LLDP::MUNGE,
+    %SNMP::Info::IEEE802dot3ad::MUNGE,
 );
 
 sub vendor {
     my $h3c = shift;
     my $mfg = $h3c->entPhysicalMfgName(1) || {};
-    return $mfg->{1} || "H3C";
+    return $mfg->{1} || "h3c";
+}
+
+sub model {
+    my $h3c = shift;
+
+    my $descr = $h3c->description();
+    if ($descr =~ /^.*\n(.*)\n/) {
+        return $1;
+    } elsif ($h3c->entPhysicalClass(2)->{2} =~ /^(3|chassis)$/) {
+        return $h3c->entPhysicalName(2)->{2};
+    } else {
+        my $id = $h3c->id();
+        return &SNMP::translateObj($id) || $id;
+    }
 }
 
 sub os {
@@ -138,14 +149,14 @@ Jeroen van Ingen
 
 =head1 SYNOPSIS
 
- # Let SNMP::Info determine the correct subclass for you. 
+ # Let SNMP::Info determine the correct subclass for you.
  my $h3c = new SNMP::Info(
                           AutoSpecify => 1,
                           Debug       => 1,
                           DestHost    => 'myrouter',
                           Community   => 'public',
                           Version     => 2
-                        ) 
+                        )
     or die "Can't connect to DestHost.\n";
 
  my $class      = $h3c->class();
@@ -161,7 +172,7 @@ Subclass for H3C & HP A-series devices
 
 =item SNMP::Info::Layer3
 
-=item SNMP::Info::LLDP
+=item SNMP::Info::IEEE802dot3ad
 
 =back
 
@@ -181,9 +192,9 @@ Subclass for H3C & HP A-series devices
 
 =item Inherited Classes' MIBs
 
-See L<SNMP::Info::Layer3> for its own MIB requirements.
+See L<SNMP::Info::IEEE802dot3ad> for its own MIB requirements.
 
-See L<SNMP::Info::LLDP> for its own MIB requirements.
+See L<SNMP::Info::Layer3> for its own MIB requirements.
 
 =back
 
@@ -193,6 +204,10 @@ These are methods that return scalar value from SNMP
 
 =over
 
+=item $h3c->model()
+
+Returns the model from C<sysObjectID> or C<entPhysicalClass>.
+
 =item $h3c->vendor()
 
 Returns value for C<entPhysicalMfgName.1>.
@@ -203,7 +218,7 @@ Returns the OS extracted from C<sysDescr>.
 
 =item $h3c->os_ver()
 
-Returns the software version. Either C<entPhysicalSoftwareRev.2> or extracted from 
+Returns the software version. Either C<entPhysicalSoftwareRev.2> or extracted from
 C<sysDescr>.
 
 =back
@@ -212,9 +227,9 @@ C<sysDescr>.
 
 See documentation in L<SNMP::Info::Layer3> for details.
 
-=head2 Globals imported from SNMP::Info::LLDP
+=head2 Globals imported from SNMP::Info::IEEE802dot3ad
 
-See documentation in L<SNMP::Info::LLDP> for details.
+See documentation in L<SNMP::Info::IEEE802dot3ad> for details.
 
 =head1 TABLE ENTRIES
 
@@ -243,8 +258,8 @@ ifIndex of the corresponding master ports.
 
 See documentation in L<SNMP::Info::Layer3> for details.
 
-=head2 Table Methods imported from SNMP::Info::LLDP
+=head2 Table Methods imported from SNMP::Info::IEEE802dot3ad
 
-See documentation in L<SNMP::Info::LLDP> for details.
+See documentation in L<SNMP::Info::IEEE802dot3ad> for details.
 
 =cut
