@@ -30,6 +30,7 @@
 package SNMP::Info::Layer3::Steelhead;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info::Layer3;
 
@@ -37,9 +38,9 @@ use SNMP::Info::Layer3;
     = qw/SNMP::Info::Layer3 Exporter/;
 @SNMP::Info::Layer3::Steelhead::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %GLOBALS %FUNCS %MIBS %MUNGE/;
+our ($VERSION, %GLOBALS, %FUNCS, %MIBS, %MUNGE);
 
-$VERSION = '3.65';
+$VERSION = '3.70';
 
 %MIBS = (
     %SNMP::Info::Layer3::MIBS,
@@ -132,10 +133,6 @@ Eric Miller
 
 Abstraction subclass for Riverbed Steelhead WAN optimization appliances.
 
-For speed or debugging purposes you can call the subclass directly, but not
-after determining a more specific class using the method above.
-
- my $riverbed = new SNMP::Info::Layer3::Steelhead(...);
 
 =head2 Inherited Classes
 
