@@ -1,5 +1,4 @@
 # SNMP::Info::Layer3::Sun
-# $Id$
 #
 # Copyright (c) 2008 Eric Miller
 # All rights reserved.
@@ -31,15 +30,16 @@
 package SNMP::Info::Layer3::Sun;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info::Layer3;
 
 @SNMP::Info::Layer3::Sun::ISA       = qw/SNMP::Info::Layer3 Exporter/;
 @SNMP::Info::Layer3::Sun::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %GLOBALS %MIBS %FUNCS %MUNGE/;
+our ($VERSION, %GLOBALS, %MIBS, %FUNCS, %MUNGE);
 
-$VERSION = '3.65';
+$VERSION = '3.70';
 
 %MIBS = ( %SNMP::Info::Layer3::MIBS, );
 
